summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Vas Crabb <vas@vastheman.com>2025-02-24 03:49:57 +1100
committer Vas Crabb <vas@vastheman.com>2025-02-24 03:49:57 +1100
commit6996150a640ddeaf5542a7e25cf27d1a0352e7e9 (patch)
tree5cebe528cf7446f39514e20f07cdbbb5796c6126
parentf55e7d697c7cd7f988b3220f476fb735476252be (diff)
Fixed some stuff:
* amiga_flop.xml: Re-added EmuTOS which was apparently lost when software lists were shuffled. * amiga_hardware.xml: Commented out software list item containing no dumps at all. * apple2_flop_clcracked.xml: Be consistent with descriptions. * dynax/ddenlovr.cpp: Use RR for Korean titles.
-rw-r--r--hash/amiga_flop.xml12
-rw-r--r--hash/amiga_hardware.xml18
-rw-r--r--hash/apple2_flop_clcracked.xml2
-rw-r--r--src/mame/dynax/ddenlovr.cpp20
4 files changed, 33 insertions, 19 deletions
diff --git a/hash/amiga_flop.xml b/hash/amiga_flop.xml
index 7146ba18af8..6ffa992220f 100644
--- a/hash/amiga_flop.xml
+++ b/hash/amiga_flop.xml
@@ -9438,5 +9438,17 @@ General Purpose Amiga Floppy Software List, anything listed here may, or may not
</part>
</software>
+ <software name="emutos93">
+ <description>EmuTOS 0.9.3</description>
+ <year>2014</year>
+ <publisher>EmuTOS development team</publisher>
+ <part name="flop1" interface="floppy_3_5">
+ <feature name="part_id" value="EmuTOS 0.9.3" />
+ <dataarea name="flop" size="901120">
+ <rom name="emutos_093.adf" size="901120" crc="96f5cc88" sha1="fa3a3aa314d50e1131a5b65a048519c76c836bd2"/>
+ </dataarea>
+ </part>
+ </software>
+
</softwarelist>
diff --git a/hash/amiga_hardware.xml b/hash/amiga_hardware.xml
index 01005a43ac8..7a7079549ac 100644
--- a/hash/amiga_hardware.xml
+++ b/hash/amiga_hardware.xml
@@ -70,16 +70,18 @@ license:CC0-1.0
<!-- Missing: 317734-05 A590 Setup Disk (Western Digital Hard Disk) -->
<!-- For use with SCSI drives -->
+ <!--
<software name="a590_scsi">
- <description>A590 Setup Disk (SCSI Hard Disk)</description>
- <year>1991</year>
- <publisher>Commodore</publisher>
- <part name="flop1" interface="floppy_3_5">
- <dataarea name="flop" size="901120">
- <rom name="317734-06_a590_scsi.adf" size="901120" status="nodump" />
- </dataarea>
- </part>
+ <description>A590 Setup Disk (SCSI Hard Disk)</description>
+ <year>1991</year>
+ <publisher>Commodore</publisher>
+ <part name="flop1" interface="floppy_3_5">
+ <dataarea name="flop" size="901120">
+ <rom name="317734-06_a590_scsi.adf" size="901120" status="nodump" />
+ </dataarea>
+ </part>
</software>
+ -->
<software name="a590_ram">
<description>A590 RAM Test Software</description>
diff --git a/hash/apple2_flop_clcracked.xml b/hash/apple2_flop_clcracked.xml
index efee71e7469..e774412dee7 100644
--- a/hash/apple2_flop_clcracked.xml
+++ b/hash/apple2_flop_clcracked.xml
@@ -56211,7 +56211,7 @@ license:CC0-1.0
</software>
<software name="trigrtri">
- <description>Trigonometry of the Right Triangle (4am crack) (version 1.0)</description>
+ <description>Trigonometry of the Right Triangle (version 1.0) (4am crack)</description>
<year>1985</year>
<publisher>Microcomputer Workshops Courseware</publisher>
<info name="programmer" value="Donald Ross, Neil Sambol, and Hugh M. McNally" />
diff --git a/src/mame/dynax/ddenlovr.cpp b/src/mame/dynax/ddenlovr.cpp
index d6d23373095..05b65166da9 100644
--- a/src/mame/dynax/ddenlovr.cpp
+++ b/src/mame/dynax/ddenlovr.cpp
@@ -45,8 +45,8 @@ Year + Game Board CPU Sound
1996 Return Of Sel Jan II NM504-2 Z80 YM2149 YM2413 M6295 TZ-2053P?
1996 Return Of Sel Jan II NM5020403 Z80 YMZ284 YM2413 M6295 70C160F011?
1997 Hana Kagerou KC80 YM2413 M6295 70C160F011
-1997 Kkot Bi Nyo 9090123-2 KC80 YM2413 M6295 70C160F011 A1010
-1997 Kkot Bi Nyo Special 9090123-3 KC80 YM2413 M6295 ?
+1997 Kkotbinyeo 9090123-2 KC80 YM2413 M6295 70C160F011 A1010
+1997 Kkotbinyeo Special 9090123-3 KC80 YM2413 M6295 ?
1997 Mj Mysterious Orient Returns NM71S0519 Z80 YMZ284 YM2413 M6295 scratched off
1998 Máquè zhōnghuá érnǚ D11107218L1 Z80 AY8910 YM2413 M6295 70C160F009
1998 Mj Reach Ippatsu KC80 YM2413 M6295 70C160F011
@@ -6071,12 +6071,12 @@ static INPUT_PORTS_START( kotbinyosu )
PORT_DIPSETTING( 0x08, DEF_STR( Off ) )
PORT_DIPSETTING( 0x00, DEF_STR( On ) )
PORT_DIPNAME( 0x10, 0x00, "Unknown 2-4" )
- PORT_DIPSETTING( 0x10, DEF_STR( Off ) ) // Shows Kkot Bi Nyo title regardless of the setting of 2-9
+ PORT_DIPSETTING( 0x10, DEF_STR( Off ) ) // Shows Kkotbinyeo title regardless of the setting of 2-9
PORT_DIPSETTING( 0x00, DEF_STR( On ) ) // Shows Speed Up title, but only if 2-9 is On
PORT_MODIFY("DSW5")
PORT_DIPNAME( 0x08, 0x00, "Unknown 2-9" )
- PORT_DIPSETTING( 0x08, DEF_STR( Off ) ) // Shows Kkot Bi Nyo title regardless of the setting of 2-4
+ PORT_DIPSETTING( 0x08, DEF_STR( Off ) ) // Shows Kkotbinyeo title regardless of the setting of 2-4
PORT_DIPSETTING( 0x00, DEF_STR( On ) ) // Shows Speed Up title, but only if 2-4 is On
INPUT_PORTS_END
@@ -10998,7 +10998,7 @@ ROM_END
/***************************************************************************
-Kkot Bi Nyo
+Kkotbinyeo
Dynax / Nakanihon / Shinwhajin
1997
@@ -11042,7 +11042,7 @@ ROM_START( kotbinyo )
ROM_LOAD( "ampal16l8.7a", 0x000, 0x104, NO_DUMP )
ROM_END
// 9090123-1 PCB. Title can be chosen via DSWs between Kkot Bi Nyo and Speed Up (스피드업)
// Speed Up seems to be just the minigames, with the Hanafuda main game disabled.
ROM_START( kotbinyosu )
ROM_REGION( 0x80000, "maincpu", 0 ) // ! KL5C80 Code !
@@ -11067,7 +11067,7 @@ ROM_END
/***************************************************************************
-Kkot Bi Nyo Special
+Kkotbinyeo Special
Dynax / Nakanihon / Shinwhajin
1997
@@ -12678,10 +12678,10 @@ GAME( 1995, ddenlovrb, ddenlovj, ddenlovr, ddenlovr, ddenlovr_state, empty_
GAME( 1996, ddenlovr, ddenlovj, ddenlovr, ddenlovr, ddenlovr_state, empty_init, ROT0, "Dynax", "Don Den Lover Vol. 1 (Hong Kong)", MACHINE_NO_COCKTAIL )
GAME( 1996, hanakanz, 0, hanakanz, hanakanz, hanakanz_state, empty_init, ROT0, "Dynax", "Hana Kanzashi (Japan)", MACHINE_NO_COCKTAIL )
-GAME( 1997, kotbinyo, hanakanz, kotbinyo, kotbinyo, hanakanz_state, empty_init, ROT0, "Dynax / Shinwhajin", "Kkot Bi Nyo (Korea)", MACHINE_NO_COCKTAIL )
-GAME( 1997, kotbinyosu, hanakanz, kotbinyo, kotbinyosu, hanakanz_state, empty_init, ROT0, "Dynax / Shinwhajin", "Speed Up / Kkot Bi Nyo (Korea)", MACHINE_NOT_WORKING | MACHINE_NO_COCKTAIL )
+GAME( 1997, kotbinyo, hanakanz, kotbinyo, kotbinyo, hanakanz_state, empty_init, ROT0, "Dynax / Shinwhajin", "Kkotbinyeo (Korea)", MACHINE_NO_COCKTAIL )
+GAME( 1997, kotbinyosu, hanakanz, kotbinyo, kotbinyosu, hanakanz_state, empty_init, ROT0, "Dynax / Shinwhajin", "Speed Up / Kkotbinyeo (Korea)", MACHINE_NOT_WORKING | MACHINE_NO_COCKTAIL )
-GAME( 1997, kotbinsp, 0, kotbinsp, kotbinsp, hanakanz_state, empty_init, ROT0, "Dynax / Shinwhajin", "Kkot Bi Nyo Special (Korea)", MACHINE_NO_COCKTAIL )
+GAME( 1997, kotbinsp, 0, kotbinsp, kotbinsp, hanakanz_state, empty_init, ROT0, "Dynax / Shinwhajin", "Kkotbinyeo Special (Korea)", MACHINE_NO_COCKTAIL )
GAME( 1996, akamaru, 0, akamaru, akamaru, ddenlovr_state, empty_init, ROT0, "Dynax (Nakanihon license)", "Panel & Variety Akamaru Q Joushou Dont-R", MACHINE_NO_COCKTAIL )
@@ -11042,7 +11042,7 @@ ROM_START( kotbinyo )
ROM_LOAD( "ampal16l8.7a", 0x000, 0x104, NO_DUMP )
ROM_END
-// 9090123-1 PCB. Title can be chosen via DSWs between Kkot Bi Nyo and Speed Up (스피드업)
+// 9090123-1 PCB. Title can be chosen via DSWs between Kkotbinyeo and Speed Up (스피드업)
// Speed Up seems to be just the minigames, with the Hanafuda main game disabled.
ROM_START( kotbinyosu )